"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.invokeTasksUsingRunMany = void 0;
const environment_1 = require("../../../utilities/environment");
const child_process_1 = require("child_process");
const { output } = require('../../../utilities/nx-imports');
function invokeTasksUsingRunMany(completedTaskReader, executionId, tasks, maxParallel) {
    let completedStatusCode = 0;
    const completedTasks = [];
    for (const g of groupByTarget(tasks)) {
        const config = g.configuration ? `--configuration=${g.configuration}` : ``;
        const parallel = maxParallel > 1 ? ` --parallel --max-parallel=${maxParallel}` : ``;
        // TODO use pnpx or yarn when needed
        const command = `npx nx run-many --target=${g.target} ${config} --projects=${g.projects.join(',')} ${g.params}${parallel}`;
        if (environment_1.VERBOSE_LOGGING) {
            output.note({
                title: `Executing: '${command}'`,
            });
        }
        try {
            (0, child_process_1.execSync)(command, {
                stdio: ['ignore', 'inherit', 'inherit'],
                env: Object.assign(Object.assign({}, process.env), { NX_CACHE_FAILURES: 'true', NX_CLOUD_DISTRIBUTED_EXECUTION_ID: executionId, NX_STREAM_OUTPUT: 'true', NX_PREFIX_OUTPUT: 'true' }),
            });
            completedTasks.push(...completedTaskReader(executionId));
        }
        catch (e) {
            if (e.status === environment_1.DISTRIBUTED_TASK_EXECUTION_INTERNAL_ERROR_STATUS_CODE) {
                throw e;
            }
            else {
                completedStatusCode = 1;
                completedTasks.push(...completedTaskReader(executionId));
            }
        }
    }
    return { completedStatusCode, completedTasks };
}
exports.invokeTasksUsingRunMany = invokeTasksUsingRunMany;
function groupByTarget(tasks) {
    const res = [];
    tasks.forEach((t) => {
        const r = res.find((rr) => rr.target === t.target && rr.configuration === t.configuration);
        if (r) {
            r.projects.push(t.projectName);
        }
        else {
            res.push({
                target: t.target,
                projects: [t.projectName],
                params: t.params,
                configuration: t.configuration,
            });
        }
    });
    return res;
}
//# sourceMappingURL=invoke-tasks.js.map